/**
 * Element einer Menge oder Liste.
 *
 * @author Owyn
 * @version 2008-05-08
 */
class Element {
    int data; // Inhalt des Elements
    Element next; // Naechstes Element

    /**
     * Erzeugt ein neues Element mit Nachfolger.
     *
     * @param data Inhalt des Elements
     * @param next Verweis auf das Nachfolgeelement oder null
     */
    Element(int data, Element next) {
        this.data = data;
        this.next = next;
    }

}

/**
 * Menge von Ganzzahlen.
 *
 * @author Owyn
 * @version 2007-05-08
 */
public class Menge {
    private Element firstElement; // Erstes Element der Menge

    /**
     * Erzeugt eine leere Menge.
     */
    Menge() {
        firstElement = null;
    }
    
    /**
     * Zugriff auf das erste Element der Menge von au&szlig;en.
     *
     * @return Verweis auf das erste Element
     */
    public Element firstElement() { return firstElement; }

    /**
     * Gibt die Anzahl der Elemente der Menge zur&uuml;ck.
     *
     * @return Anzahl der Elemente
     */
    public int groesse() {
        Element current = firstElement;
        int count = 0;
        while (current != null) { // Menge durchlaufen
            count++; // Zaehlen
            current = current.next; // Naechstes Element
        }
        return count; // Anzahl zurueckgeben
    }

    /**
     * Testet, ob eine Ganzzahl schon in der Menge enthalten ist.
     *
     * @param data Ganzzahl
     * @return true, wenn data in der Menge enthalten ist, sonst false.
     */
    public boolean istEnthalten(int data) {
        Element current = firstElement;
        while (current != null) { // Menge durchlaufen
            if (current.data == data) return true; // Gefunden!
            current = current.next; // Naechstes Element
        }
        return false; // Nicht gefunden!
    }

    /**
     * F&uuml;gt eine Ganzzahl in die Menge ein, sofern sie noch nicht vorhanden ist.
     *
     * @param data Ganzzahl
     * @return true, wenn das Element eingef&uuml;gt wurde, sonst false.
     */
    public boolean fuegeEin(int data) {
        if (istEnthalten(data)) return false; // Element schon vorhanden?

        // Wenn nein: neues Element erzeugen und vor dem ersten Element einfuegen
        Element newElement = new Element(data, firstElement);
        firstElement = newElement; // Erstes Element der Menge aktualisieren
        // auch moeglich: firstElement = new Element(data, firstElement);

        return true; // Element wurde eingefuegt
    }

    /**
     * Entfernt eine Ganzzahl aus der Menge, sofern sie vorhanden ist.
     *
     * @param data Ganzzahl
     * @return true, wenn das Element entfernt wurde, sonst false.
     */
    public boolean entferne(int data) {
        if (firstElement == null) return false; // Leere Menge
        if (firstElement.data == data) { // Als erstes Element gefunden
            firstElement = firstElement.next; // Entfernen
            return true; // Methode ist hier zu Ende!
        }
        Element current = firstElement;
        while (current.next != null) { // Menge durchlaufen
            if (current.next.data == data) { // Gefunden
                current.next = current.next.next; // Entfernen
                return true; // Methode ist hier zu Ende!
            }
            current = current.next; // Naechstes Element
        }
        return false; // Nicht gefunden!
    }

    /**
     * Gibt eine Text-Darstellung der Menge zur&uuml;ck.
     *
     * @return Darstellung nach dem Muster &quot;1 -> 2 -> (X)&quot;
     */
    public String toString() {

        // ...
        return ""; // Diese Zeile loeschen!

    }

    /**
     * Vereinigt die aktuelle Menge mit der Menge m.
     *
     * @param m Menge (wird ver&auml;ndert!)
     * @return nichts, aber die Menge m enth&auml;lt die Vereinigungsmenge.
     */
    public void union(Menge m) {

        // ...

    }


    /**
     * Bildet die Schnittmenge der aktuellen Menge mit der Menge m.
     *
     * @param m Menge (wird ver&auml;ndert!)
     * @return nichts, aber die Menge m enth&auml;lt die Schnittmenge.
     */
    public void intersect(Menge m) {

        // ...

    }

}
